@@ -73,7 +73,10 @@ static char cvtIn[] = {
     20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
     30, 31, 32, 33, 34, 35};
 
-
+
+
+#if !((defined(WIN32) || defined(_WIN32)) && (_MSC_VER >= 1800))
+
 /**Convert an ASCII string into an unsigned long long integer.
  *
  * @param[in]  string  String of ASCII digits, possibly preceded by white
@@ -284,3 +287,5 @@ strtoull(const char *string, char **endPtr, int base)
 
     return (unsigned longlong)-1;
 }
+
+#endif
